summaryrefslogtreecommitdiff
path: root/vendor/thecodingmachine/safe/generated/shmop.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/thecodingmachine/safe/generated/shmop.php')
-rw-r--r--vendor/thecodingmachine/safe/generated/shmop.php39
1 files changed, 8 insertions, 31 deletions
diff --git a/vendor/thecodingmachine/safe/generated/shmop.php b/vendor/thecodingmachine/safe/generated/shmop.php
index 04ba57cb5..aa5d8f49c 100644
--- a/vendor/thecodingmachine/safe/generated/shmop.php
+++ b/vendor/thecodingmachine/safe/generated/shmop.php
@@ -7,15 +7,15 @@ use Safe\Exceptions\ShmopException;
/**
* shmop_delete is used to delete a shared memory block.
*
- * @param resource $shmid The shared memory block resource created by
+ * @param resource $shmop The shared memory block resource created by
* shmop_open
* @throws ShmopException
*
*/
-function shmop_delete($shmid): void
+function shmop_delete($shmop): void
{
error_clear_last();
- $result = \shmop_delete($shmid);
+ $result = \shmop_delete($shmop);
if ($result === false) {
throw ShmopException::createFromPhpError();
}
@@ -25,42 +25,19 @@ function shmop_delete($shmid): void
/**
* shmop_read will read a string from shared memory block.
*
- * @param resource $shmid The shared memory block identifier created by
+ * @param resource $shmop The shared memory block identifier created by
* shmop_open
* @param int $start Offset from which to start reading
* @param int $count The number of bytes to read.
* 0 reads shmop_size($shmid) - $start bytes.
* @return string Returns the data.
* @throws ShmopException
*
*/
-function shmop_read($shmid, int $start, int $count): string
+function shmop_read($shmop, int $offset, int $size): string
{
error_clear_last();
- $result = \shmop_read($shmid, $start, $count);
- if ($result === false) {
- throw ShmopException::createFromPhpError();
- }
- return $result;
-}
-
-
-/**
- * shmop_write will write a string into shared memory block.
- *
- * @param resource $shmid The shared memory block identifier created by
- * shmop_open
- * @param string $data A string to write into shared memory block
- * @param int $offset Specifies where to start writing data inside the shared memory
- * segment.
- * @return int The size of the written data.
- * @throws ShmopException
- *
- */
-function shmop_write($shmid, string $data, int $offset): int
-{
- error_clear_last();
- $result = \shmop_write($shmid, $data, $offset);
+ $result = \shmop_read($shmop, $offset, $size);
if ($result === false) {
throw ShmopException::createFromPhpError();
}
@@ -25,42 +25,19 @@ function shmop_delete($shmid): void
* shmop_open
- * @param int $start Offset from which to start reading
- * @param int $count The number of bytes to read.
+ * @param int $offset Offset from which to start reading
+ * @param int $size The number of bytes to read.
* 0 reads shmop_size($shmid) - $start bytes.
* @return string Returns the data.